package MGA::Mirrors::View::Mail;

use strict;
use base 'Catalyst::View::TT';
use Mail::Mailer;
use MGA::Mirrors;

__PACKAGE__->config(
    TEMPLATE_EXTENSION => '.tt',
    INCLUDE_PATH => MGA::Mirrors->path_to( 'root', 'mail' ),
);

=head1 NAME

MGA::Mirrors::View::TT - TT View for MGA::Mirrors

=head1 DESCRIPTION

TT View for MGA::Mirrors. 

=cut

sub render {
    my ($self, $c, $template, $args) = @_;

    $ENV{MAILADDRESS} = $args->{From};
    my $mailer = new Mail::Mailer 'smtp', Server => (MGA::Mirrors->config->{smtp} || 'localhost');
    eval { 
        $mailer->open({
            (map { $_ => $args->{$_} } grep { $_ !~ /^(mail)$/ } keys %{ $args || {}}),
            'Content-Type' => 'text/plain; charset=UTF-8; format=flowed',
            'Content-Transfer-Encoding' => '8bit',
            'X-MGA-Mirrors-version' => $MGA::Mirrors::DB::VERSION,
        });
        print $mailer
        Catalyst::View::TT::render($self, $c, $template, { %{ $args->{mail} || {} }, c => $c });
        $mailer->close;
    };
    if ($@) {
        $c->stash->{mail_error} = $@;
    }
}

=head1 SEE ALSO

L<MGA::Mirrors>

=head1 AUTHOR

Thauvin Olivier

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself or CeCILL.

=cut

1;
